=======
Credits
=======

Development Lead
----------------

.. {# pkglts, doc.authors

* revesansparole, <revesansparole@gmail.com>

.. #}

Contributors
------------

.. {# pkglts, doc.contributors

* revesansparole <revesansparole@gmail.com>
* ThT12 <ThT12@ThT12.fr>
* pradal <christophe.pradal@inria.fr>
* Simon Artzet <simon.artzet@gmail.com>
* Christophe Pradal <christophe.pradal@inria.fr>

.. #}
